==> zio-aws-apigatewayv2_2.12-5.17.183.1-sources.jar: zio/aws/apigatewayv2/model/CreateStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  StringWithLengthBetween0And2048,
  StringWithLengthBetween1And1600,
  __string,
  __boolean,
  StringWithLengthBetween0And1024,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateStageRequest(
    accessLogSettings: Optional[zio.aws.apigatewayv2.model.AccessLogSettings] =
      Optional.Absent,
    apiId: __string,
    autoDeploy: Optional[__boolean] = Optional.Absent,
    clientCertificateId: Optional[Id] = Optional.Absent,
    defaultRouteSettings: Optional[zio.aws.apigatewayv2.model.RouteSettings] =
      Optional.Absent,
    deploymentId: Optional[Id] = Optional.Absent,
    description: Optional[StringWithLengthBetween0And1024] = Optional.Absent,
    routeSettings: Optional[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings]
    ] = Optional.Absent,
    stageName: StringWithLengthBetween1And128,
    stageVariables: Optional[Map[__string, StringWithLengthBetween0And2048]] =
      Optional.Absent,
    tags: Optional[Map[__string, StringWithLengthBetween1And1600]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest = {
    import CreateStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
      .builder()
      .optionallyWith(accessLogSettings.map(value => value.buildAwsValue()))(
        _.accessLogSettings
      )
      .apiId(apiId: java.lang.String)
      .optionallyWith(autoDeploy.map(value => value: java.lang.Boolean))(
        _.autoDeploy
      )
      .optionallyWith(
        clientCertificateId.map(value => Id.unwrap(value): java.lang.String)
      )(_.clientCertificateId)
      .optionallyWith(defaultRouteSettings.map(value => value.buildAwsValue()))(
        _.defaultRouteSettings
      )
      .optionallyWith(
        deploymentId.map(value => Id.unwrap(value): java.lang.String)
      )(_.deploymentId)
      .optionallyWith(
        description.map(value =>
          StringWithLengthBetween0And1024.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        routeSettings.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.routeSettings)
      .stageName(
        StringWithLengthBetween1And128.unwrap(stageName): java.lang.String
      )
      .optionallyWith(
        stageVariables.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (StringWithLengthBetween0And2048
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.stageVariables)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (StringWithLengthBetween1And1600
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.CreateStageRequest.wrap(buildAwsValue())
}
object CreateStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.CreateStageRequest =
      zio.aws.apigatewayv2.model.CreateStageRequest(
        accessLogSettings.map(value => value.asEditable),
        apiId,
        autoDeploy.map(value => value),
        clientCertificateId.map(value => value),
        defaultRouteSettings.map(value => value.asEditable),
        deploymentId.map(value => value),
        description.map(value => value),
        routeSettings.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        stageName,
        stageVariables.map(value => value),
        tags.map(value => value)
      )
    def accessLogSettings
        : Optional[zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly]
    def apiId: __string
    def autoDeploy: Optional[__boolean]
    def clientCertificateId: Optional[Id]
    def defaultRouteSettings
        : Optional[zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    def deploymentId: Optional[Id]
    def description: Optional[StringWithLengthBetween0And1024]
    def routeSettings: Optional[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    ]
    def stageName: StringWithLengthBetween1And128
    def stageVariables: Optional[Map[__string, StringWithLengthBetween0And2048]]
    def tags: Optional[Map[__string, StringWithLengthBetween1And1600]]
    def getAccessLogSettings: ZIO[
      Any,
      AwsError,
      zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly
    ] = AwsError.unwrapOptionField("accessLogSettings", accessLogSettings)
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAutoDeploy: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("autoDeploy", autoDeploy)
    def getClientCertificateId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("clientCertificateId", clientCertificateId)
    def getDefaultRouteSettings: ZIO[
      Any,
      AwsError,
      zio.aws.apigatewayv2.model.RouteSettings.ReadOnly
    ] = AwsError.unwrapOptionField("defaultRouteSettings", defaultRouteSettings)
    def getDeploymentId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("deploymentId", deploymentId)
    def getDescription: ZIO[Any, AwsError, StringWithLengthBetween0And1024] =
      AwsError.unwrapOptionField("description", description)
    def getRouteSettings: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.RouteSettings.ReadOnly
    ]] = AwsError.unwrapOptionField("routeSettings", routeSettings)
    def getStageName: ZIO[Any, Nothing, StringWithLengthBetween1And128] =
      ZIO.succeed(stageName)
    def getStageVariables
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween0And2048]] =
      AwsError.unwrapOptionField("stageVariables", stageVariables)
    def getTags
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And1600]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ) extends zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly {
    override val accessLogSettings
        : Optional[zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accessLogSettings())
        .map(value => zio.aws.apigatewayv2.model.AccessLogSettings.wrap(value))
    override val apiId: __string = impl.apiId(): __string
    override val autoDeploy: Optional[__boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.autoDeploy())
      .map(value => value: __boolean)
    override val clientCertificateId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.clientCertificateId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val defaultRouteSettings
        : Optional[zio.aws.apigatewayv2.model.RouteSettings.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.defaultRouteSettings())
        .map(value => zio.aws.apigatewayv2.model.RouteSettings.wrap(value))
    override val deploymentId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.deploymentId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val description: Optional[StringWithLengthBetween0And1024] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween0And1024(value)
        )
    override val routeSettings: Optional[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.routeSettings())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> zio.aws.apigatewayv2.model.RouteSettings
              .wrap(value)
          })
          .toMap
      )
    override val stageName: StringWithLengthBetween1And128 =
      zio.aws.apigatewayv2.model.primitives
        .StringWithLengthBetween1And128(impl.stageName())
    override val stageVariables
        : Optional[Map[__string, StringWithLengthBetween0And2048]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stageVariables())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: __string) -> zio.aws.apigatewayv2.model.primitives
                .StringWithLengthBetween0And2048(value)
            })
            .toMap
        )
    override val tags
        : Optional[Map[__string, StringWithLengthBetween1And1600]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: __string) -> zio.aws.apigatewayv2.model.primitives
                .StringWithLengthBetween1And1600(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ): zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.126.1-sources.jar: zio/aws/apigatewayv2/model/CreateStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  StringWithLengthBetween0And2048,
  StringWithLengthBetween1And1600,
  __string,
  __boolean,
  StringWithLengthBetween0And1024,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateStageRequest(
    accessLogSettings: Option[zio.aws.apigatewayv2.model.AccessLogSettings] =
      None,
    apiId: __string,
    autoDeploy: Option[__boolean] = None,
    clientCertificateId: Option[Id] = None,
    defaultRouteSettings: Option[zio.aws.apigatewayv2.model.RouteSettings] =
      None,
    deploymentId: Option[Id] = None,
    description: Option[StringWithLengthBetween0And1024] = None,
    routeSettings: Option[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings]
    ] = None,
    stageName: StringWithLengthBetween1And128,
    stageVariables: Option[Map[__string, StringWithLengthBetween0And2048]] =
      None,
    tags: Option[Map[__string, StringWithLengthBetween1And1600]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest = {
    import CreateStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
      .builder()
      .optionallyWith(accessLogSettings.map(value => value.buildAwsValue()))(
        _.accessLogSettings
      )
      .apiId(__string.unwrap(apiId): java.lang.String)
      .optionallyWith(
        autoDeploy.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.autoDeploy)
      .optionallyWith(
        clientCertificateId.map(value => Id.unwrap(value): java.lang.String)
      )(_.clientCertificateId)
      .optionallyWith(defaultRouteSettings.map(value => value.buildAwsValue()))(
        _.defaultRouteSettings
      )
      .optionallyWith(
        deploymentId.map(value => Id.unwrap(value): java.lang.String)
      )(_.deploymentId)
      .optionallyWith(
        description.map(value =>
          StringWithLengthBetween0And1024.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        routeSettings.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.routeSettings)
      .stageName(
        StringWithLengthBetween1And128.unwrap(stageName): java.lang.String
      )
      .optionallyWith(
        stageVariables.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(
                key
              ): java.lang.String) -> (StringWithLengthBetween0And2048
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.stageVariables)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(
                key
              ): java.lang.String) -> (StringWithLengthBetween1And1600
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.CreateStageRequest.wrap(buildAwsValue())
}
object CreateStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.CreateStageRequest =
      zio.aws.apigatewayv2.model.CreateStageRequest(
        accessLogSettings.map(value => value.asEditable),
        apiId,
        autoDeploy.map(value => value),
        clientCertificateId.map(value => value),
        defaultRouteSettings.map(value => value.asEditable),
        deploymentId.map(value => value),
        description.map(value => value),
        routeSettings.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        stageName,
        stageVariables.map(value => value),
        tags.map(value => value)
      )
    def accessLogSettings
        : Option[zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly]
    def apiId: __string
    def autoDeploy: Option[__boolean]
    def clientCertificateId: Option[Id]
    def defaultRouteSettings
        : Option[zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    def deploymentId: Option[Id]
    def description: Option[StringWithLengthBetween0And1024]
    def routeSettings: Option[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    ]
    def stageName: StringWithLengthBetween1And128
    def stageVariables: Option[Map[__string, StringWithLengthBetween0And2048]]
    def tags: Option[Map[__string, StringWithLengthBetween1And1600]]
    def getAccessLogSettings: ZIO[
      Any,
      AwsError,
      zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly
    ] = AwsError.unwrapOptionField("accessLogSettings", accessLogSettings)
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAutoDeploy: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("autoDeploy", autoDeploy)
    def getClientCertificateId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("clientCertificateId", clientCertificateId)
    def getDefaultRouteSettings: ZIO[
      Any,
      AwsError,
      zio.aws.apigatewayv2.model.RouteSettings.ReadOnly
    ] = AwsError.unwrapOptionField("defaultRouteSettings", defaultRouteSettings)
    def getDeploymentId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("deploymentId", deploymentId)
    def getDescription: ZIO[Any, AwsError, StringWithLengthBetween0And1024] =
      AwsError.unwrapOptionField("description", description)
    def getRouteSettings: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.RouteSettings.ReadOnly
    ]] = AwsError.unwrapOptionField("routeSettings", routeSettings)
    def getStageName: ZIO[Any, Nothing, StringWithLengthBetween1And128] =
      ZIO.succeed(stageName)
    def getStageVariables
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween0And2048]] =
      AwsError.unwrapOptionField("stageVariables", stageVariables)
    def getTags
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And1600]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ) extends zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly {
    override val accessLogSettings
        : Option[zio.aws.apigatewayv2.model.AccessLogSettings.ReadOnly] = scala
      .Option(impl.accessLogSettings())
      .map(value => zio.aws.apigatewayv2.model.AccessLogSettings.wrap(value))
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val autoDeploy: Option[__boolean] = scala
      .Option(impl.autoDeploy())
      .map(value => zio.aws.apigatewayv2.model.primitives.__boolean(value))
    override val clientCertificateId: Option[Id] = scala
      .Option(impl.clientCertificateId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val defaultRouteSettings
        : Option[zio.aws.apigatewayv2.model.RouteSettings.ReadOnly] = scala
      .Option(impl.defaultRouteSettings())
      .map(value => zio.aws.apigatewayv2.model.RouteSettings.wrap(value))
    override val deploymentId: Option[Id] = scala
      .Option(impl.deploymentId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val description: Option[StringWithLengthBetween0And1024] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween0And1024(value)
      )
    override val routeSettings: Option[
      Map[__string, zio.aws.apigatewayv2.model.RouteSettings.ReadOnly]
    ] = scala
      .Option(impl.routeSettings())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives.__string(
              key
            ) -> zio.aws.apigatewayv2.model.RouteSettings.wrap(value)
          })
          .toMap
      )
    override val stageName: StringWithLengthBetween1And128 =
      zio.aws.apigatewayv2.model.primitives
        .StringWithLengthBetween1And128(impl.stageName())
    override val stageVariables
        : Option[Map[__string, StringWithLengthBetween0And2048]] = scala
      .Option(impl.stageVariables())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives
              .__string(key) -> zio.aws.apigatewayv2.model.primitives
              .StringWithLengthBetween0And2048(value)
          })
          .toMap
      )
    override val tags: Option[Map[__string, StringWithLengthBetween1And1600]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.apigatewayv2.model.primitives
                .__string(key) -> zio.aws.apigatewayv2.model.primitives
                .StringWithLengthBetween1And1600(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateStageRequest
  ): zio.aws.apigatewayv2.model.CreateStageRequest.ReadOnly = new Wrapper(impl)
}
